<?php

if (file_exists('../../blocks/autoattend/lib.php')) {
	include_once('../../blocks/autoattend/lib.php');
}



function homeroom_get_all_member_ids()
{
	global $DB, $attendPlugin;

	$ids = array();

	// autoattend
	if ($attendPlugin=='autoattend') {
		$sql = 'SELECT DISTINCT studentid FROM {autoattend_students}';
	}

	// attendance
	else if ($attendPlugin=='attendance') {
		$sql = 'SELECT DISTINCT studentid FROM {attendance_log}';
	}

	//
	$users = $DB->get_records_sql($sql);
	foreach ($users as $user) {
		if ($user->studentid>0) $ids[] = $user->studentid;
	}

	return $ids;
}



function homeroom_get_attend_course($user)
{
	global $DB, $attendPlugin;

	$courses = array();

	// autoattend
	if ($attendPlugin=='autoattend') {
		$sort = 'ORDER BY st.calledtime DESC';
		$stqry = 'SELECT DISTINCT se.courseid FROM {autoattend_students} st, {autoattend_sessions} se '.
						'WHERE st.studentid=? AND st.attsid=se.id '.$sort;
		$clqry = 'SELECT classid FROM {autoattend_classifies} WHERE studentid=? AND courseid=?';
		//
		$courseids = $DB->get_records_sql($stqry, array($user->id));
		foreach ($courseids as $courseid) {
			$ret = $DB->get_record_sql($clqry, array($user->id, $courseid->courseid));
			if (!$ret or $ret->classid>0) {
				$courses[] = $DB->get_record('course', array('id'=>$courseid->courseid));
			}
		}
	}

	// attendance
	else if ($attendPlugin=='attendance') {
		$sort  = 'ORDER BY st.timetaken DESC';
		$stqry = 'SELECT DISTINCT ad.course FROM {attendance_log} st, {attendance_sessions} se, {attendance} ad '.
						'WHERE st.studentid=? AND st.sessionid=se.id AND se.attendanceid=ad.id '.$sort;
		//
		$courseids = $DB->get_records_sql($stqry, array($user->id));
		foreach ($courseids as $courseid) {
			$courses[] = $DB->get_record('course', array('id'=>$courseid->course));
		}
	}

	return $courses;
}




function homeroom_get_user_summary($userid, $courseid)
{
	global $attendPlugin;

	// autoattend
	if ($attendPlugin=='autoattend') {
		$ret = autoattend_get_user_summary($userid, $courseid);
	}

	// attendance
	else if ($attendPlugin=='attendance') {
		$ret = homeroom_get_attendance_summary($userid, $courseid);
	}

	return $ret;
}




function homeroom_get_all_attends($user, $sort, $order)
{
	global $DB, $attendPlugin;

	$attends  = array();

	if ($sort=='date') {
		$sort = 'ORDER BY se.sessdate '.$order;
	}
	// default
	else {
		$sort = 'ORDER BY se.sessdate DESC';
	}

	// autoattend
	if ($attendPlugin=='autoattend') {
		$items = 'st.*, se.sessdate, se.starttime, se.endtime, se.description, se.courseid';
		$stqry = 'SELECT '.$items.' FROM {autoattend_students} st, {autoattend_sessions} se '.
						'WHERE st.studentid=? AND st.attsid=se.id '.$sort;
		$clqry = 'SELECT classid FROM {autoattend_classifies} WHERE studentid=? AND courseid=?';

		$sessions = $DB->get_records_sql($stqry, array($user->id));

		$i = 0;
		foreach ($sessions as $session) {
			$ret = $DB->get_record_sql($clqry, array($user->id, $session->courseid));
			if (!$ret or $ret->classid>0) {
				$attends[$i] = $session;
				$attends[$i]->course = $DB->get_record('course', array('id'=>$session->courseid));
				if (!$ret) $attends[$i]->classid = 0;
				else	   $attends[$i]->classid = $ret->classid;
				$i++;
			}
		}
	}

	// attendance
	else if ($attendPlugin=='attendance') {
		$items = 'st.*, se.sessdate, se.duration, se.description, ad.course, ss.acronym';
		$stqry = 'SELECT '.$items.' FROM {attendance_log} st, {attendance_sessions} se, {attendance} ad, {attendance_statuses} ss '.
						'WHERE st.studentid=? AND st.sessionid=se.id AND se.attendanceid=ad.id AND st.statusid=ss.id '.$sort;

		$sessions = $DB->get_records_sql($stqry, array($user->id));
		$sessions = homeroom_attendance_to_autoattend($sessions);

		$i = 0;
		foreach ($sessions as $session) {
			$attends[$i] = $session;
			$attends[$i]->course = $DB->get_record('course', array('id'=>$session->courseid));
			$i++;
		}
	}

	return $attends;
}




function homeroom_get_classname($classid)
{
	global $attendPlugin;

	// autoattend
	if ($attendPlugin=='autoattend') {
		$ret = autoattend_get_user_classname($classid);
	}

	// attendance
	else if ($attendPlugin=='attendance') {
		$ret = ' - ';
	}

	return $ret;
}



function  homeroom_get_ipresolv_url($ip)
{
	global $attendPlugin;

	// autoattend
	if ($attendPlugin=='autoattend') {
		$ret = autoattend_get_ipresolv_url($ip);
	}

	// attendance
	else if ($attendPlugin=='attendance') {
		require_once('jbxl/jbxl_tools.php');
		$ret = jbxl_get_ipresolv_url($ip);
	}

	return $ret;
}





////////////////////////////////////////////////////////////////////////////////////////////////////
//

function homeroom_attendance_to_autoattend(array $sessions)
{
	$attends = array();

	$i = 0;
	foreach ($sessions as $session) {
		$attends[$i] 			 = $session;
		$attends[$i]->attsid 	 = $session->sessionid;
		$attends[$i]->status 	 = $session->acronym;
		if ($attends[$i]->status=='A') $attends[$i]->status = 'X';
		$attends[$i]->called 	 = 'M';
		$attends[$i]->calledby 	 = $session->takenby;
		$attends[$i]->calledtime = $session->timetaken;
		$attends[$i]->ipaddress  = ' - ';
		$attends[$i]->starttime  = $session->sessdate;
		$attends[$i]->endtime 	 = $session->sessdate + $session->duration;
		$attends[$i]->courseid	 = $session->course;
		$attends[$i]->classid 	 = 0;
		$i++;
	}

	return $attends;
}




// $summary['userid']   : ユーザID
// $summary['courseid'] : コースID
// $summary['attitems'] : 学生の各授業のRawデータ（配列）
// $summary['complete'] : 出席コマ数（早退，遅刻を含む）
// $summary['grade']    : 出席点
// $summary['percent']  : 出席率（出席点ベース）
// $summary['P']		: 正常出席数 
// $summary['X']		: 欠席数．クローズしたセッションで Y の物を含む． 
// $summary['L']		: 遅刻数 
// $summary['E']		: 早退数 
// $summary['maxgrade'] : 最高出席点（皆勤の場合の出席点）
//
// X $summary['Y']		  : 未了数．ただしクローズしたセッションは X とする． 
// X $summary['settings'] : 出席点の配分Rawデータ（配列）
// X $summary['classid']  : クラスID
// X $summary['classname']: クラス名
// X $summary['mingrade'] : 最低出席点（全欠の場合の出席点）
// X $summary['leccount'] : 実施した授業のコマ数
////
function homeroom_get_attendance_summary($userid, $courseid) 
{
	global $CFG, $DB;

	$ntime = time();

	$sort  = 'ORDER BY se.sessdate ASC';
	$items = 'st.*, se.sessdate, se.duration, se.description, ad.course, ss.acronym, ss.grade, ad.grade as maxgrade';
	$stqry = 'SELECT '.$items.' FROM {attendance_log} st, {attendance_sessions} se, {attendance} ad, {attendance_statuses} ss '.
						'WHERE st.studentid=? AND ad.course=? AND st.sessionid=se.id AND se.attendanceid=ad.id AND st.statusid=ss.id '.$sort;

	$attitems = $DB->get_records_sql($stqry, array($userid, $courseid));
	if (!$attitems) return false;
	$attitems = homeroom_attendance_to_autoattend($attitems);

	$summary = array();
	$summary['userid']   = $userid;
	$summary['courseid'] = $courseid;
	$summary['attitems'] = $attitems;

	$status = array('P', 'X', 'L', 'E', 'Y');
	$summary['settings'] = array();
	foreach ($status as $st) {
		$summary[$st] = 0;
		$summary['settings'][$st] = new StdClass();
		$summary['settings'][$st]->status = $st;
	}

	$complete = 0;
	$leccount = 0;
	$grade = 0;
	if ($attitems) {
		foreach($attitems as $att) {
			if ($att->status) {
				$complete++;
				$grade += $att->grade;
				$summary[$att->status]++;
			}
			else {
				$summary['Y']++;
			}
		}
		$leccount++;
	}
	$summary['complete'] = $complete;	       // 出席コマ数（早退，遅刻を含む）
	$summary['leccount'] = $leccount;
	$sessnum = $complete;

	//
	$summary['grade'] 	 = $grade;
	$summary['maxgrade'] = $attitems[0]->maxgrade;
	$summary['mingrade'] = 0;
	//
	$gradelevel = $summary['maxgrade'] - $summary['mingrade'];
	if ($gradelevel!=0) {
		$percent = 100*($summary['grade']-$summary['mingrade'])/$gradelevel;
		$summary['percent'] = sprintf('%0.1f', $percent);
	}
	else {
		$summary['percent'] = ' - ';
	}

	$summary['classid']  = 0;
	$summary['classname']= ' - ';

	return $summary;
}

