<?php

define('HOMEROOM_AUTHOR_FORBIDDEN', 0);
define('HOMEROOM_AUTHOR_ONESELF',	1);
define('HOMEROOM_AUTHOR_ALL',		2);
define('HOMEROOM_AUTHOR_SPECIFIC',  3);

define('DEFAULT_PAGE_SIZE', 15);


include_once('jbxl/jbxl_tools.php');
include_once('homeroom_exdb_lib.php');

include_once('timezonedef.php');



/////////////////////////////////////////////////////////////////////////////

function homeroom_get_authoriz($roomid, $userid)
{
	global $DB;

	$ret = $DB->get_record('homeroom_user', array('roomid'=>$roomid, 'userid'=>$userid));
	//
	if (!$ret) {
		$insert = new StdClass();
		$insert->roomid = $roomid;
		$insert->userid = $userid;
		$insert->authorize = HOMEROOM_AUTHOR_ONESELF;
		$insert->timemodified = time();
		$DB->insert_record('homeroom_user', $insert);
		$author = HOMEROOM_AUTHOR_ONESELF;
	}
	else {
		$author = $ret->authorize;
	}

	return $author;
}



function homeroom_get_members($roomid, $userid)
{
	global $DB;

	$members = array();

	$author = homeroom_get_authoriz($roomid, $userid);

	if ($author==HOMEROOM_AUTHOR_ONESELF) {
		$members[] = $DB->get_record('user', array('id'=>$userid, 'deleted'=>0));
	}
	//
	else if ($author==HOMEROOM_AUTHOR_ALL or $author==HOMEROOM_AUTHOR_SPECIFIC) {
		//
		$users = $DB->get_records('homeroom_student', array('roomid'=>$roomid, 'teacher'=>$userid));
		if ($users) {
			foreach ($users as $user) {
				if ($user->selected) {
					$members[] = $DB->get_record('user', array('id'=>$user->student, 'deleted'=>0));
				}
			}
		}
		else {
			if ($author==HOMEROOM_AUTHOR_ALL) {
				$members = homeroom_get_all_members();
			}
		}
	}

	return $members;
}



function homeroom_get_all_members()
{
	global $DB;
	
	//
	$members = array();	
	$ids = homeroom_get_all_member_ids();

	foreach ($ids as $id) {
		$members[] = $DB->get_record('user', array('id'=>$id, 'deleted'=>0));
	}
	return $members;
}   




function homeroom_has_show_permit($userid, $members)
{
	$perm = false;

	foreach($members as $member) {
		if ($member->id==$userid) {
			$perm = true;
			break;
		}
	}

	return $perm;
}
 



function homeroom_get_course_list($user, $limit=0)
{
	global $wwwBaseUrl;

	$courselisting = '';

	//$mycourses = enrol_get_all_users_courses($user->id, true, NULL, 'visible DESC,sortorder ASC');
	$mycourses = homeroom_get_attend_course($user);
	if ($mycourses) {
		$shown = 0;
		foreach ($mycourses as $mycourse) {
			if ($mycourse->category) {
				$ccontext = context_course::instance($mycourse->id);
				if ($mycourse->visible==0) {
					if (!has_capability('moodle/course:viewhiddencourses', $ccontext)) {
						continue;
					}
				}
				if ($shown>0) $courselisting .= ', ';
				$linkurl = $wwwBaseUrl.'&amp;userid='.$user->id.'&amp;crsid='.$mycourse->id.'&amp;action=crsreport';			
				$courselisting .= "<a href=\"$linkurl\">".$ccontext->get_context_name(false).'</a>';			
			}
			//
			$shown++;
			if($limit!=0 and $shown==$limit) {
				$courselisting .= '...';
				break;
			}
		}
	}

	return $courselisting;
}



function homeroom_get_course_array($user, $limit=0)
{
	global $DB, $wwwBaseUrl;

	$courses = array();

	$mycourses = homeroom_get_attend_course($user);
	if ($mycourses) {
		$shown = 0;
		foreach ($mycourses as $mycourse) {
			if ($mycourse->category) {
				$ccontext = context_course::instance($mycourse->id);
				if ($mycourse->visible==0) {
					if (!has_capability('moodle/course:viewhiddencourses', $ccontext)) {
						continue;
					}
				}
				$course = $DB->get_record('course', array('id'=>$mycourse->id));
				if ($course) $courses[$mycourse->id] = $course;			
			}
			//
			$shown++;
			if($limit!=0 and $shown==$limit) {
				break;
			}
		}
	}

	return $courses;
}



/////////////////////////////////////////////////////////////////////////////////////////////
// $user is user object or user id
//
function homeroom_get_user_link($user, $pattern='fullname')
{
	global $DB, $CFG;
	if (!is_object($user)) $user = $DB->get_record('user', array('id'=>$user));
	if (!$user) return '';

	$user_name = homeroom_get_user_name($user, $pattern);
	$link = '<a href='.$CFG->wwwroot.'/user/view.php?id='.$user->id.'>'.$user_name.'</a>';

	return $link;
}



function homeroom_get_user_name($user, $pattern='fullname')
{
	global $DB;

	if (!is_object($user)) $user = $DB->get_record('user', array('id'=>$user));

	if		($pattern=='firstname') $user_name = $user->firstname;
	else if ($pattern=='lastname')  $user_name = $user->lastname;
	else							$user_name = fullname($user);

	return $user_name;
}



function homeroom_get_fullnamehead($name_pattern, $firstname, $lastname, $deli='')
{
	global $CFG;

	if ($name_pattern=='fullname') {
		if ($CFG->fullnamedisplay=='lastname firstname') { // for better view (dlnsk)
			if ($deli=='') $fullnamehead = "$lastname $firstname";
			else		   $fullnamehead = "$lastname ".$deli." $firstname";
		}
		else {
			if ($deli=='') $fullnamehead = "$firstname $lastname";
			else		   $fullnamehead = "$firstname ".$deli." $lastname";
		}
	}
	else if ($name_pattern=='lastname') {
		$fullnamehead = "$lastname";
	}
	else {
		$fullnamehead = "$firstname";
	}

	return $fullnamehead;
}



function homeroom_get_user_info($user_id)
{
	global $DB;

	$ufields = user_picture::fields('u');   // u.id, u.picture, u.firstname, u.lastname, u.imagealt, u.email
	$sql = 'SELECT '.$ufields.' FROM {user} u WHERE u.id='.$user_id;
	$ret = $DB->get_record_sql($sql);

	return $ret;
}



function homeroom_print_error_messagebox($str, $id, $view_url='mod/homeroom')
{
	global $OUTPUT, $CFG;

	echo $OUTPUT->box_start('generalbox boxaligncenter boxwidthwide');

	if ($str!='' and $str!=null) {
		echo '<h2><font color="red"><div align="center">';
		echo get_string($str, 'homeroom');
		echo '</div></font></h2>';
	}

	echo $OUTPUT->continue_button($CFG->wwwroot.'/'.$view_url.'/view.php?id='.$id);
	echo $OUTPUT->box_end();
	echo $OUTPUT->footer();
}




//




